/* Copyright (c) 1999 Regents of the University of California */

/******************************************************************************
 *
 *	UC Berkeley, 1999
 *	Haarm-Pieter Duiker		duiker@cs.berkeley.edu
 *	Tim Hawkins			tsh@cs.berkeley.edu
 *	Paul Debevec			debevec@cs.berkeley.edu
 * 
 *	Implementing modified version of algorithm presented in
 *	Recovering High Dynamic Range Radiance Maps from Photographs
 *	Debevec, Malik 1997
 *
 *  mkhdr.h
 *	Forward declarations for mhdr.c
 *
 *****************************************************************************/

/* Separate data maps will be created for each channel.
   The set of bases can be reused by each channel. The
   computation of each will be done separately. */
typedef struct {
	float** data;
} radianceMap;

typedef double curveElement;

typedef struct {
	FILE* image;
	float exposure;
	short** data;
} expImage;

typedef struct {
  float *trace;
  float weight;
  int image, value, selected;
} pixelTrace;

void processCommmandLine(int, char**);
int processInputFile(expImage*, const char*);

void writeOutCurve(curveElement**, char*);
int readInCurve(curveElement**, char*);

void writeOutRadianceFile(radianceMap*, char*);
short** processImageFile(FILE*, char*);

/* Functions hard coded to work with 8 bit values */
double weight(float, void*, int, int);
double bellWeight(float);

void generateCurve(int, curveElement*, expImage*);
void generateOneChannel(int, float*, curveElement*, expImage*);

void createRadMapFromCurve(radianceMap*, curveElement**, expImage*);
void createRadMapAndCurve(radianceMap*, curveElement**, expImage*);

